# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, lib, ... }:
let
  home-manager = builtins.fetchTarball "https://github.com/nix-community/home-manager/archive/master.tar.gz";
  wofi-catppuccin = builtins.fetchTarball "https://github.com/quantumfate/wofi/archive/master.tar.gz";
  starship-catppuccin = builtins.fetchTarball "https://github.com/catppuccin/starship/archive/master.tar.gz";
in
{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
      ./firefox/firefox.nix
      ./alacritty/alacritty.nix
      ./hyprland/hyprland.nix
      ./fonts.nix
      (import "${home-manager}/nixos")
    ];
  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.initrd.kernelModules = [ "amdgpu" ];  

  networking.hostName = "ark-desktop-nixos"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Enable networking
  networking.networkmanager.enable = true;

  # Enable network manager applet
  programs.nm-applet.enable = true;

  # Set your time zone.
  time.timeZone = "America/Los_Angeles";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "en_US.UTF-8";
    LC_IDENTIFICATION = "en_US.UTF-8";
    LC_MEASUREMENT = "en_US.UTF-8";
    LC_MONETARY = "en_US.UTF-8";
    LC_NAME = "en_US.UTF-8";
    LC_NUMERIC = "en_US.UTF-8";
    LC_PAPER = "en_US.UTF-8";
    LC_TELEPHONE = "en_US.UTF-8";
    LC_TIME = "en_US.UTF-8";
  };

  environment.sessionVariables = {
    WLR_NO_HARDWARE_CURSORS = "1";
    NIXOS_OZONE_WL = "1";
  };

  hardware = {
    opengl.enable = true;
  };

  # Enable CUPS to print documents.
  services.printing.enable = true;

  # Enable sound with pipewire.
  sound.enable = true;
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    # If you want to use JACK applications, uncomment this
    #jack.enable = true;

    # use the example session manager (no others are packaged yet so this is enabled by default,
    # no need to redefine it in your config for now)
    #media-session.enable = true;
  };

  # Enable touchpad support (enabled default in most desktopManager).
  # services.xserver.libinput.enable = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.ark = {
    isNormalUser = true;
    description = "ark-lamp-umbrella";
    extraGroups = [ "networkmanager" "wheel" ];

    shell = pkgs.fish;
  };

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    waybar # Toolbar
    dunst # Notification Handler
    libnotify # Notification Library
    lxqt.lxqt-policykit # Polkit
    protonup-qt
    pkgsi686Linux.gperftools
    uxn
    adwsteamgtk
    pinentry-curses
    keychain
    (steam.override { extraLibraries = pkgs: [ pkgs.gperftools ]; })
  ];

  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };

  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  # services.openssh.enable = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
  networking.firewall.enable = true;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.11";

  xdg.portal = {
    enable = true;
    extraPortals = [ pkgs.xdg-desktop-portal-gtk ];
  };

  home-manager.users.ark = {
    /* The home.stateVersion option does not have a default and must be set */
    home.stateVersion = "24.05";
    /* Here goes the rest of your home-manager config, e.g. home.packages = [ pkgs.foo ]; */
    home.packages = [
      pkgs.bun
      pkgs.elixir
      pkgs.blender
    ];
    programs = {
      vscode = {
        enable = true;
        enableUpdateCheck = false;
        enableExtensionUpdateCheck = false;
        package = pkgs.vscodium;
        extensions = with pkgs.vscode-extensions; [
          catppuccin.catppuccin-vsc
          catppuccin.catppuccin-vsc-icons
          jnoortheen.nix-ide
          editorconfig.editorconfig
          bmalehorn.vscode-fish
        ];
        userSettings = {
          "workbench.colorTheme" = "Catppuccin Macchiato";
          "workbench.iconTheme" = "catppuccin-macchiato";
          "workbench.activityBar.location" = "side";
          "window.menuBarVisibility" = "hidden";
          "editor.fontFamily" = "'BlexMono Nerd Font Mono', 'monospace', monospace";
        };
      };
      wofi = {
        enable = true;
        style = builtins.readFile "${wofi-catppuccin}/src/macchiato/style.css";
      };
      lsd = {
        enable = true;
      };
      starship = {
        enable = true;
        enableFishIntegration = true;
        settings = {
          add_newline = false;
          format = lib.concatStrings [
            "$character"
          ];
          character = {
            success_symbol = "󰔶 ~";
            error_symbol = "󰔷 ~";
          };
          palette = "catppuccin_macchiato";
        } // 
        builtins.fromTOML (
          builtins.readFile(
            "${starship-catppuccin}/palettes/macchiato.toml"
          )
        );
      };
      git = {
        enable = true;
        userName = "ark-lamp-umbrella";
        userEmail = "ark-lamp-umbrella@noreply.codeberg.org";
        signing = {
          key = "15078E3940CB5C65B450A86D15E48F7B97025652";
          signByDefault = true;
        };
      };
    };
  };
  security.polkit.enable = true;
  programs.fish = {
    enable = true;
    # Enable starship prompt
    interactiveShellInit = ''
    set fish_greeting

    keychain --eval /home/ark/.ssh/id_ed25519 | source && clear
    source (/home/ark/.nix-profile/bin/starship init fish --print-full-init | psub)
    
    alias ls=lsd
    '';
  };
  programs.steam = {
    enable = true;
    remotePlay.openFirewall = true; # Open ports in the firewall for Steam Remote Play
    dedicatedServer.openFirewall = true; # Open ports in the firewall for Source Dedicated Server
  };
  hardware.opengl.driSupport = true; # This is already enabled by default
  hardware.opengl.driSupport32Bit = true; # For 32 bit applications
}
